@@ -3,7 +3,9 @@ import audalign.fingerprint as fingerprint
 import audalign.recognize as recognize
 import audalign.align as align
 import audalign.visrecognize as visrecognize
+import audalign.correcognize as correcognize
 from pydub.exceptions import CouldntDecodeError
+from pydub.utils import mediainfo
 from typing import Tuple
 from functools import partial
 import multiprocessing
@@ -17,9 +19,9 @@ class Audalign:
     # Names that appear in match information
     CONFIDENCE = "confidence"
     MATCH_TIME = "match_time"
-    OFFSET_SAMPLES = "offset_samples"
+    OFFSET_SAMPLES = "offset_frames"
     OFFSET_SECS = "offset_seconds"
-    LOCALITY = "locality"
+    LOCALITY = "locality_frames"
     LOCALITY_SECS = "locality_seconds"
 
     def __init__(
@@ -54,22 +56,14 @@ class Audalign:
         4 gives the highest accuracy, but can take several gigabytes of memory for a couple files.
         Accuracy settings are acheived by manipulations in fingerprinting variables.
 
-        Parameters
-        ----------
-        arg1 : str
-            Optional file path to load json or pickle file of already fingerprinted files
-        multiprocessing : bool
-            option to turn off multiprocessing
-        num_processors : int
-            number of processors or threads to use for multiprocessing. Uses all if not given
-        hash_style : str
-            which hash style to use : ['base','panako_mod','panako', 'base_three']
-        accuracy : int
-            which accuracy level 1-4
-        threshold: int
-            filters fingerprints below threshold
-        noisereduce: bool
-            runs noise reduce on audio
+        Args
+            arg1 (str): Optional file path to load json or pickle file of already fingerprinted files
+            multiprocessing (bool): option to turn off multiprocessing
+            num_processors (int): number of processors or threads to use for multiprocessing. Uses all if not given
+            hash_style (str): which hash style to use : ['base','panako_mod','panako', 'base_three']
+            accuracy (int): which accuracy level 1-4
+            threshold(int): filters fingerprints below threshold
+            noisereduce(bool): runs noise reduce on audio
         """
 
         self.file_names = []
@@ -108,10 +102,8 @@ class Audalign:
 
         Specific values for accuracy levels were chosen semi-arbitrarily from experimentation to give a few good options.
 
-        Parameters
-        ----------
-            accuracy : int
-                which accuracy level: 1-4
+        Args
+            accuracy (int): which accuracy level: 1-4
         """
         if accuracy < 1 or accuracy > 4:
             print("Accuracy must be between 1 and 4")
@@ -160,7 +152,20 @@ class Audalign:
         Args:
             threshold ([int]): [threshold]
         """
-        fingerprint.threshold = threshold
+        self.freq_threshold = threshold
+        self._set_freq_threshold(freq_threshold=threshold)
+
+    @staticmethod
+    def _set_freq_threshold(freq_threshold: int) -> None:
+        fingerprint.threshold = freq_threshold
+
+    def get_freq_threshold(self):
+        """Returns the frequency threshold
+
+        Returns:
+            [int]: frequency threshold
+        """
+        return self.freq_threshold
 
     def set_multiprocessing(self, true_or_false: bool) -> None:
         """Sets to true for on or false for off
@@ -200,10 +205,8 @@ class Audalign:
         """
         Loads/adds saved json or pickle file into current audalign object
 
-        Parameters
-        ----------
-        filename : str
-            must be either json or pickle extension
+        Args
+            filename (str): must be either json or pickle extension
 
         Returns
         -------
@@ -245,14 +248,10 @@ class Audalign:
         """
         Fingerprints all files in given directory and all subdirectories
 
-        Parameters
-        ----------
-        path : str
-            path to directory to be fingerprinted
-        plot : boolean
-            if true, plots the peaks to be fingerprinted on a spectrogram
-        extensions : list[str]
-            specify which extensions to fingerprint
+        Args
+            path (str): path to directory to be fingerprinted
+            plot (boolean): if true, plots the peaks to be fingerprinted on a spectrogram
+            extensions (list[str]): specify which extensions to fingerprint
 
         Returns
         -------
@@ -277,14 +276,10 @@ class Audalign:
 
         Fingerprints all files in given directory and all subdirectories
 
-        Parameters
-        ----------
-        path : str
-            path to directory to be fingerprinted
-        plot : boolean
-            if true, plots the peaks to be fingerprinted on a spectrogram
-        extensions : list[str]
-            specify which extensions to fingerprint
+        Args
+            path (str): path to directory to be fingerprinted
+            plot (boolean): if true, plots the peaks to be fingerprinted on a spectrogram
+            extensions (list[str]): specify which extensions to fingerprint
 
         Returns
         -------
@@ -310,6 +305,7 @@ class Audalign:
             hash_style=self.hash_style,
             plot=plot,
             accuracy=self.accuracy,
+            freq_threshold=self.freq_threshold,
         )
 
         if self.multiprocessing == True:
@@ -347,19 +343,20 @@ class Audalign:
         return result
 
     def fingerprint_file(
-        self, file_path: str, set_file_name: str = None, plot: bool = False
+        self,
+        file_path: str,
+        start_end: tuple = None,
+        set_file_name: str = None,
+        plot: bool = False,
     ) -> None:
         """
         Fingerprints given file and adds to fingerprinted files
 
-        Parameters
-        ----------
-        file_path : str
-            path to word to be fingerprinted
-        set_file_name : str
-            option to set file name manually rather than use file name in file_path
-        plot : boolean
-            if true, plots the peaks to be fingerprinted on a spectrogram
+        Args
+            file_path (str): path to word to be fingerprinted
+            start_end (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
+            set_file_name (str): option to set file name manually rather than use file name in file_path
+            plot (boolean): if true, plots the peaks to be fingerprinted on a spectrogram
 
         Returns
         -------
@@ -370,28 +367,31 @@ class Audalign:
             print(f"{file_name} already fingerprinted")
             return None
 
-        file_name, hashes = self._fingerprint_file(file_path, set_file_name, plot)
+        file_name, hashes = self._fingerprint_file(
+            file_path, start_end=start_end, set_file_name=set_file_name, plot=plot
+        )
         if file_name != None:
             self.fingerprinted_files.append([file_name, hashes])
             self.file_names.append(file_name)
             self.total_fingerprints += len(hashes)
 
     def _fingerprint_file(
-        self, file_path: str, set_file_name: str = None, plot: bool = False
+        self,
+        file_path: str,
+        start_end: tuple = None,
+        set_file_name: str = None,
+        plot: bool = False,
     ):
         """
         Worker function for fingerprint_file
 
         Fingerprints given file and adds to fingerprinted files
 
-        Parameters
-        ----------
-        file_path : str
-            path to word to be fingerprinted
-        set_file_name : str
-            option to set file name manually rather than use file name in file_path
-        plot : boolean
-            if true, plots the peaks to be fingerprinted on a spectrogram
+        Args
+            file_path (str): path to word to be fingerprinted
+            start_end (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
+            set_file_name (str): option to set file name manually rather than use file name in file_path
+            plot (boolean): if true, plots the peaks to be fingerprinted on a spectrogram
 
         Returns
         -------
@@ -401,14 +401,22 @@ class Audalign:
         file_name, hashes = _fingerprint_worker(
             file_path,
             self.hash_style,
+            start_end=start_end,
             plot=plot,
             accuracy=self.accuracy,
+            freq_threshold=self.freq_threshold,
         )
         file_name = set_file_name or file_name
         return [file_name, hashes]
 
     def recognize(
-        self, file_path: str, filter_matches: int = 1, locality=None, *args, **kwargs
+        self,
+        file_path: str,
+        filter_matches: int = 1,
+        locality: float = None,
+        start_end: tuple = None,
+        *args,
+        **kwargs,
     ) -> None:
         """
         Recognizes given file against already fingerprinted files
@@ -417,14 +425,11 @@ class Audalign:
         Does not recognize against files with same name and extention
         Locality option used to only return match results within certain second range
 
-        Parameters
-        ----------
-        file_path : str
-            file path of target file to recognize
-        filter_matches : int
-            filters all matches lower than given argument, 1 is recommended
-        locality : float
-            filters matches to only count within locality. In seconds
+        Args
+            file_path (str): file path of target file to recognize
+            filter_matches (int): filters all matches lower than given argument, 1 is recommended
+            locality (float): filters matches to only count within locality. In seconds
+            start_end (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
 
         Returns
         -------
@@ -437,13 +442,64 @@ class Audalign:
         """
 
         return recognize.recognize(
-            self, file_path, filter_matches, locality, *args, **kwargs
+            self,
+            file_path=file_path,
+            filter_matches=filter_matches,
+            locality=locality,
+            start_end=start_end,
+            *args,
+            **kwargs,
+        )
+
+    def correcognize(
+        self,
+        target_file_path: str,
+        against_file_path: str,
+        start_end_target: tuple = None,
+        start_end_against: tuple = None,
+        filter_matches: float = 0.5,
+        match_len_filter: int = 30,
+        sample_rate: int = fingerprint.DEFAULT_FS,
+        plot: bool = False,
+        **kwargs,
+    ):
+        """Uses cross correlation to find alignment
+
+        Faster than visrecognize or recognize and more useful for amplitude
+        based alignments
+
+        Args:
+            target_file_path (str): File to recognize
+            against_file_path (str): File to recognize against
+            start_end_target (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
+            start_end_against (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
+            filter_matches (float, optional): Filters based on confidence. Ranges between 0 and 1. Defaults to 0.5.
+            match_len_filter (int, optional): Limits number of matches returned. Defaults to 30.
+            sample_rate (int, optional): Decodes audio file to this sample rate. Defaults to fingerprint.DEFAULT_FS.
+            plot (bool, optional): Plots. Defaults to False.
+            kwargs: additional arguments for scipy.signal.find_peaks.
+
+        Returns:
+            dict: dictionary of recognition information
+        """
+        return correcognize.correcognize(
+            target_file_path,
+            against_file_path,
+            start_end_target=start_end_target,
+            start_end_against=start_end_against,
+            filter_matches=filter_matches,
+            match_len_filter=match_len_filter,
+            sample_rate=sample_rate,
+            plot=plot,
+            **kwargs,
         )
 
     def visrecognize(
         self,
         target_file_path: str,
         against_file_path: str,
+        start_end_target: tuple = None,
+        start_end_against: tuple = None,
         img_width: float = 1.0,
         volume_threshold: float = 215.0,
         volume_floor: float = 10.0,
@@ -460,6 +516,8 @@ class Audalign:
         Args:
             target_file_path (str): File to recognize.
             against_file_path (str): Recognize against.
+            start_end_target (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
+            start_end_against (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
             img_width (float): width of spectrogram image for recognition.
             volume_threshold (float): doesn't find stats for sections with max volume below threshold.
             volume_floor (float): ignores volume levels below floow.
@@ -480,6 +538,8 @@ class Audalign:
         return visrecognize.visrecognize(
             target_file_path,
             against_file_path,
+            start_end_target=start_end_target,
+            start_end_against=start_end_against,
             img_width=img_width,
             volume_threshold=volume_threshold,
             volume_floor=volume_floor,
@@ -491,10 +551,51 @@ class Audalign:
             plot=plot,
         )
 
+    def correcognize_directory(
+        self,
+        target_file_path: str,
+        against_directory: str,
+        start_end: tuple = None,
+        filter_matches: float = 0.5,
+        match_len_filter: int = 30,
+        sample_rate: int = fingerprint.DEFAULT_FS,
+        plot: bool = False,
+        **kwargs,
+    ):
+        """Uses cross correlation to find alignment
+
+        Faster than visrecognize or recognize and more useful for amplitude
+        based alignments
+
+        Args:
+            target_file_path (str): File to recognize
+            against_directory (str): Directory to recognize against
+            start_end (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
+            filter_matches (float, optional): Filters based on confidence. Ranges between 0 and 1. Defaults to 0.5.
+            match_len_filter (int, optional): Limits number of matches returned. Defaults to 30.
+            sample_rate (int, optional): Decodes audio file to this sample rate. Defaults to fingerprint.DEFAULT_FS.
+            plot (bool, optional): Plots. Defaults to False.
+            kwargs: additional arguments for scipy.signal.find_peaks.
+
+        Returns:
+            dict: dictionary of recognition information
+        """
+        return correcognize.correcognize_directory(
+            target_file_path,
+            against_directory,
+            start_end=start_end,
+            filter_matches=filter_matches,
+            match_len_filter=match_len_filter,
+            sample_rate=sample_rate,
+            plot=plot,
+            **kwargs,
+        )
+
     def visrecognize_directory(
         self,
         target_file_path: str,
         against_directory: str,
+        start_end: tuple = None,
         img_width: float = 1.0,
         volume_threshold: float = 215.0,
         volume_floor: float = 10.0,
@@ -511,6 +612,7 @@ class Audalign:
         Args:
             target_file_path (str): File to recognize.
             against_directory (str): Recognize against all files in directory.
+            start_end (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
             img_width (float): width of spectrogram image for recognition.
             volume_threshold (int): doesn't find stats for sections with max volume below threshold.
             volume_floor (float): ignores volume levels below floow.
@@ -531,6 +633,7 @@ class Audalign:
         return visrecognize.visrecognize_directory(
             target_file_path,
             against_directory,
+            start_end=start_end,
             img_width=img_width,
             volume_threshold=volume_threshold,
             volume_floor=volume_floor,
@@ -542,45 +645,54 @@ class Audalign:
             plot=plot,
         )
 
-    def write_processed_file(self, file_path: str, destination_file: str) -> None:
+    def write_processed_file(
+        self,
+        file_path: str,
+        destination_file: str,
+        start_end: tuple = None,
+    ) -> None:
         """
         writes given file to the destination file after processing for fingerprinting
 
-        Parameters
-        ----------
-        file_path : str
-            file path of audio file
-        destination_file : str
-            file path and name to write file to
+        Args
+            file_path (str): file path of audio file
+            destination_file (str): file path and name to write file to
+            start_end (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
 
         Returns
         -------
         None
         """
-        filehandler.read(file_path, wrdestination=destination_file)
+        filehandler.read(
+            filename=file_path,
+            wrdestination=destination_file,
+            start_end=start_end,
+        )
 
-    def plot(self, file_path: str) -> None:
+    def plot(
+        self,
+        file_path: str,
+        start_end: tuple = None,
+    ) -> None:
         """
         Plots the file_path's peak chart
 
-        Parameters
-        ----------
-        file_path : str
-            file to plot
+        Args
+            file_path (str): file to plot
+            start_end (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
 
         Returns
         -------
         None
         """
-        self._fingerprint_file(file_path, plot=True)
+        self._fingerprint_file(file_path, start_end=start_end, plot=True)
 
     def clear_fingerprints(self) -> None:
         """
         Resets audalign object to brand new state
 
-        Parameters
-        ----------
-        None
+        Args
+            None
 
         Returns
         -------
@@ -595,10 +707,11 @@ class Audalign:
         target_file: str,
         directory_path: str,
         destination_path: str = None,
+        start_end: tuple = None,
         write_extension: str = None,
-        use_fingerprints: bool = True,
+        technique: str = "fingerprints",
         alternate_strength_stat: str = None,
-        filter_matches: int = 1,
+        filter_matches: float = None,
         locality: float = None,
         volume_threshold: float = 216,
         volume_floor: float = 10.0,
@@ -606,6 +719,8 @@ class Audalign:
         horiz_scaling: float = 1.0,
         img_width: float = 1.0,
         calc_mse: bool = False,
+        cor_sample_rate: int = fingerprint.DEFAULT_FS,
+        **kwargs,
     ):
         """matches and relative offsets for all files in directory_path using only target file,
         aligns them, and writes them to destination_path if given. Uses fingerprinting by defualt,
@@ -615,10 +730,11 @@ class Audalign:
             target_file (str): File to find alignments against
             directory_path (str): Directory to align against
             destination_path (str, optional): Directory to write alignments to
+            start_end (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
             write_extension (str, optional): audio file format to write to. Defaults to None.
-            use_fingerprints (bool, optional): Fingerprints if True, visual recognition if False. Defaults to True.
+            technique (str, optional): options are "fingerprints", "visual", "correlation"
             alternate_strength_stat (str, optional): confidence for fingerprints, ssim for visual, mse or count also work for visual. Defaults to None.
-            filter_matches (int, optional): filter matches level for fingerprinting. Defaults to 1.
+            filter_matches (int, float, optional): filter matches level for fingerprinting. Defaults to 1.
             locality (float, optional): In seconds for fingerprints, only matches files within given window sizes
             volume_threshold (float, optional): volume threshold for visual recognition. Defaults to 216.
             volume_floor (float): ignores volume levels below floow.
@@ -626,6 +742,8 @@ class Audalign:
             horiz_scaling (float): scales horizontally to speed up calculations. Smaller numbers have smaller images. Affects alignment granularity.
             img_width (float, optional): width of image comparison for visual recognition
             calc_mse (bool): also calculates mse for each shift if true. If false, uses default mse 20000000
+            cor_sample_rate (int): optionally change the sample rate if using correlation
+            kwargs: additional arguments for scipy.signal.find_peaks
 
         Returns:
             dict: dict of file name with shift as value along with match info
@@ -645,7 +763,13 @@ class Audalign:
             total_alignment = {}
             file_names_and_paths = {}
 
-            if use_fingerprints:
+            if technique == "fingerprints":
+
+                if filter_matches is None:
+                    filter_matches = 1
+
+                if start_end is not None:
+                    self.fingerprint_file(target_file, start_end=start_end)
 
                 all_against_files = filehandler.find_files(directory_path)
                 all_against_files_full = [x[0] for x in all_against_files]
@@ -660,13 +784,17 @@ class Audalign:
                 self.fingerprint_directory(directory_path)
 
                 alignment = self.recognize(
-                    target_file, filter_matches=filter_matches, locality=locality
+                    target_file,
+                    filter_matches=filter_matches,
+                    locality=locality,
+                    start_end=start_end,
                 )
 
-            else:
+            elif technique == "visual":
                 alignment = self.visrecognize_directory(
                     target_file_path=target_file,
                     against_directory=directory_path,
+                    start_end=start_end,
                     volume_threshold=volume_threshold,
                     volume_floor=volume_floor,
                     vert_scaling=vert_scaling,
@@ -674,6 +802,21 @@ class Audalign:
                     img_width=img_width,
                     calc_mse=calc_mse,
                 )
+            elif technique == "correlation":
+                if filter_matches is None:
+                    filter_matches = 0.5
+                alignment = self.correcognize_directory(
+                    target_file_path=target_file,
+                    against_directory=directory_path,
+                    start_end=start_end,
+                    filter_matches=filter_matches,
+                    sample_rate=cor_sample_rate,
+                    **kwargs,
+                )
+            else:
+                raise NameError(
+                    f'Technique parameter must be fingerprint, visual, or correlation, not "{technique}"'
+                )
 
             file_names_and_paths[target_name] = target_file
             total_alignment[target_name] = alignment
@@ -690,10 +833,12 @@ class Audalign:
                     file_names_and_paths[os.path.basename(file_path)] = file_path
 
             if not alternate_strength_stat:
-                if use_fingerprints:
+                if technique == "fingerprints":
                     alternate_strength_stat = self.CONFIDENCE
-                else:
+                elif technique == "visual":
                     alternate_strength_stat = "ssim"
+                else:
+                    alternate_strength_stat = self.CONFIDENCE
             files_shifts = align.find_most_matches(
                 total_alignment, strength_stat=alternate_strength_stat
             )
@@ -731,30 +876,28 @@ class Audalign:
         directory_path: str,
         destination_path: str = None,
         write_extension: str = None,
-        filter_matches: int = 1,
+        technique: str = "fingerprints",
+        filter_matches: float = None,
         locality: float = None,
+        cor_sample_rate: int = fingerprint.DEFAULT_FS,
+        **kwargs,
     ):
         """
         Finds matches and relative offsets for all files in directory_path, aligns them, and writes them to destination_path
 
-        Parameters
-        ----------
-        directory_path : str
-            String of directory for alignment
-
-        destination_path : str
-            String of path to write alignments to
-
-        write_extension : str
-            if given, writes all alignments with given extension (ex. ".wav" or "wav")
-
-        locality : float
-            Only recognizes against fingerprints in given width. In seconds
+        Args
+            directory_path (str): String of directory for alignment
+            destination_path (str): String of path to write alignments to
+            write_extension (str): if given, writes all alignments with given extension (ex. ".wav" or "wav")
+            technique (str): either "fingerprints" or "correlation"
+            filter_matches (float): filters based on confidence.
+            locality (float): Only recognizes against fingerprints in given width. In seconds
+            cor_sample_rate (int): Sampling rate for correlation
+            **kwargs: Additional arguments for finding peaks in correlation
 
         Returns
         -------
-        files_shifts : dict{float}
-            dict of file name with shift as value
+            files_shifts (dict{float}): dict of file name with shift as value
         """
 
         self.file_names, temp_file_names = [], self.file_names
@@ -771,7 +914,18 @@ class Audalign:
                 if not os.path.exists(destination_path):
                     os.makedirs(destination_path)
 
-            self.fingerprint_directory(directory_path)
+            if technique == "fingerprints":
+                if filter_matches is None:
+                    filter_matches = 1
+                self.fingerprint_directory(directory_path)
+            elif technique == "correlation":
+                if filter_matches is None:
+                    filter_matches = 0.5
+                self.file_names = filehandler.get_audio_files_directory(directory_path)
+            else:
+                raise NameError(
+                    f'Technique parameter must be fingerprint, visual, or correlation, not "{technique}"'
+                )
 
             total_alignment = {}
             file_names_and_paths = {}
@@ -780,9 +934,18 @@ class Audalign:
             for file_path, _ in filehandler.find_files(directory_path):
                 name = os.path.basename(file_path)
                 if name in self.file_names:
-                    alignment = self.recognize(
-                        file_path, filter_matches=filter_matches, locality=locality
-                    )
+                    if technique == "fingerprints":
+                        alignment = self.recognize(
+                            file_path, filter_matches=filter_matches, locality=locality
+                        )
+                    elif technique == "correlation":
+                        alignment = self.correcognize_directory(
+                            file_path,
+                            directory_path,
+                            filter_matches=filter_matches,
+                            sample_rate=cor_sample_rate,
+                            **kwargs,
+                        )
                     file_names_and_paths[name] = file_path
                     total_alignment[name] = alignment
 
@@ -826,19 +989,29 @@ class Audalign:
         """
         Writes files to destination_path with specified shift
 
-        Parameters
-        ----------
-        files_shifts : dict{float}
-            dict with file path as key and shift as value
-        destination_path : str
-            folder to write file to
-        names_and_paths : dict{str}
-            dict with name as key and path as value
+        Args
+            files_shifts (dict{float}): dict with file path as key and shift as value
+            destination_path (str): folder to write file to
+            names_and_paths (dict{str}): dict with name as key and path as value
         """
         filehandler.shift_write_files(
             files_shifts, destination_path, names_and_paths, write_extension
         )
 
+    @staticmethod
+    def get_metadata(file_path: str):
+        """Returns metadata of audio or video file
+
+        if file_path is not a valid file or is a directory, returns empty dict
+
+        Args:
+            file_path (str): file path to file
+
+        Returns:
+            dict: dict of tags and values
+        """
+        return mediainfo(filepath=file_path)
+
     @staticmethod
     def write_shifted_file(
         file_path: str, destination_path: str, offset_seconds: float
@@ -846,30 +1019,30 @@ class Audalign:
         """
         Writes file to destination_path with specified shift in seconds
 
-        Parameters
-        ----------
-        file_path : str
-            file path of file to shift
-        destination_path : str
-            where to write file to and file name
-        offset_seconds : float
-            how many seconds to shift, can't be negative
+        Args
+            file_path (str): file path of file to shift
+            destination_path (str): where to write file to and file name
+            offset_seconds (float): how many seconds to shift, can't be negative
         """
         filehandler.shift_write_file(file_path, destination_path, offset_seconds)
 
     @staticmethod
-    def convert_audio_file(file_path: str, destination_path: str):
+    def convert_audio_file(
+        file_path: str,
+        destination_path: str,
+        start_end: tuple = None,
+    ):
         """
         Convert audio file to type specified in destination path
 
-        Parameters
-        ----------
-        file_path : str
-            file path of file to shift
-        destination_path : str
-            where to write file to and file name
+        Args
+            file_path (str): file path of file to shift
+            destination_path (str): where to write file to and file name
+            start_end (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
         """
-        filehandler.convert_audio_file(file_path, destination_path)
+        filehandler.read(
+            filename=file_path, wrdestination=destination_path, start_end=start_end
+        )
 
     @staticmethod
     def remove_noise_file(
@@ -952,33 +1125,34 @@ class Audalign:
 def _fingerprint_worker(
     file_path: str,
     hash_style="panako_mod",
+    start_end: tuple = None,
     plot=False,
     accuracy=2,
+    freq_threshold=200,
 ) -> Tuple:
     """
     Runs the file through the fingerprinter and returns file_name and hashes
 
-    Parameters
-    ----------
-    file_path : str
-        file_path to be fingerprinted
-    plot : bool
-        displays the plot of the peaks if true
-    amp_min : int
-        minimum amplitude to be considered a peak
+    Args
+        file_path (str): file_path to be fingerprinted
+        hash_style (str): which hash style to use : ['base','panako_mod','panako', 'base_three']
+        start_end (tuple(float, float), optional): Silences before and after start and end. (0, -1) Silences last second, (5.4, 0) silences first 5.4 seconds
+        plot (bool): displays the plot of the peaks if true
+        accuracy (int): which accuracy level 1-4
+        freq_threshold (int): what the freq threshold is in specgram bins
 
     Returns
     -------
-    file_name : str, hashes : dict{str: [int]}
-        file_name and hash dictionary
+        file_name (str, hashes : dict{str: [int]}): file_name and hash dictionary
     """
 
     Audalign._set_accuracy(accuracy)
+    Audalign._set_freq_threshold(freq_threshold)
 
     file_name = os.path.basename(file_path)
 
     try:
-        channel, _ = filehandler.read(file_path)
+        channel, _ = filehandler.read(file_path, start_end=start_end)
     except FileNotFoundError:
         print(f'"{file_path}" not found')
         return None, None
